@@ -9,7 +9,7 @@ fluxConst <- list(poundsDay = new("fluxUnit",
                                   unitExpressTiny = expression("Flux (lbs/d)"),
                                   unitEstimate = expression("Estimated flux in pounds/day"),
                                   unitEstimateTiny = expression("Est. flux (lbs/d)"),
-                                  unitUSGS = "Flux in pounds per day",
+                                  unitUSGS = "Flux, in pounds per day",
                                   shortCode = 1),
                   tonsDay = new("fluxUnit", 
                                 shortName = "   tons/day  ",  
@@ -19,7 +19,7 @@ fluxConst <- list(poundsDay = new("fluxUnit",
                                 unitExpressTiny = expression("Flux (tons/d)"),
                                 unitEstimate = expression("Estimated flux in tons/day"),
                                 unitEstimateTiny = expression("Est. flux (tons/d)"),
-                                unitUSGS = "Flux in tons per day",
+                                unitUSGS = "Flux, in tons per day",
                                 shortCode = 2),
                   kgDay = new("fluxUnit", 
                               shortName = "    kg/day  ",   
@@ -29,7 +29,7 @@ fluxConst <- list(poundsDay = new("fluxUnit",
                               unitExpressTiny = expression("Flux (kg/d)"),
                               unitEstimate = expression("Estimated flux in kg/day"),
                               unitEstimateTiny = expression("Est. flux (kg/d)"),
-                              unitUSGS = "Flux in kilograms per day",
+                              unitUSGS = "Flux, in kilograms per day",
                               shortCode = 3),
                   thousandKgDay = new("fluxUnit", 
                                       shortName = " 10^3 kg/day",
@@ -39,7 +39,7 @@ fluxConst <- list(poundsDay = new("fluxUnit",
                                       unitExpressTiny = expression(paste("Flux ", "(", 10^3*kg/d, ")")),
                                       unitEstimate = expression(paste("Estimated flux in ",10^3*kg/day)),
                                       unitEstimateTiny = expression(paste("Est. flux ", "(", 10^3*kg/d, ")")),
-                                      unitUSGS = "Flux in thousands of kilograms per day",
+                                      unitUSGS = "Flux, in thousands of kilograms per day",
                                       shortCode = 4),
                   tonsYear = new("fluxUnit", 
                                  shortName = "   tons/yr  ",
@@ -49,7 +49,7 @@ fluxConst <- list(poundsDay = new("fluxUnit",
                                  unitExpressTiny = expression("Flux (tons/yr)"),
                                  unitEstimate = expression("Estimated flux in tons/year"),
                                  unitEstimateTiny = expression("Est. flux (tons/yr)"),
-                                 unitUSGS = "Flux in tons per year",
+                                 unitUSGS = "Flux, in tons per year",
                                  shortCode = 5),
                   thousandTonsYear = new("fluxUnit", 
                                          shortName = "  10^3 tons/yr",
@@ -59,7 +59,7 @@ fluxConst <- list(poundsDay = new("fluxUnit",
                                          unitExpressTiny = expression(paste("Flux ", "(", 10^3*tons/yr, ")")),
                                          unitEstimate = expression(paste("Estimated flux in ",10^3*tons/yr)),
                                          unitEstimateTiny = expression(paste("Est. flux ", "(", 10^3*tons/yr, ")")),
-                                         unitUSGS = "Flux in thousands of tons per year",
+                                         unitUSGS = "Flux, in thousands of tons per year",
                                          shortCode = 6),
                   millionTonsYear = new("fluxUnit",
                                         shortName = "  10^6 tons/yr",
@@ -69,7 +69,7 @@ fluxConst <- list(poundsDay = new("fluxUnit",
                                         unitExpressTiny = expression(paste("Flux ", "(", 10^6*tons/yr, ")")),
                                         unitEstimate = expression(paste("Estimated flux in ",10^6*tons/yr)),
                                         unitEstimateTiny = expression(paste("Est. flux ", "(", 10^6*tons/yr, ")")),
-                                        unitUSGS = "Flux in millions of tons per year",
+                                        unitUSGS = "Flux, in millions of tons per year",
                                         shortCode = 7),
                   thousandKgYear = new("fluxUnit",
                                        shortName = "   10^3 kg/yr",
@@ -79,7 +79,7 @@ fluxConst <- list(poundsDay = new("fluxUnit",
                                        unitExpressTiny = expression(paste("Flux ", "(", 10^3*kg/yr, ")")),
                                        unitEstimate = expression(paste("Estimated flux in ",10^3*kg/yr)),
                                        unitEstimateTiny = expression(paste("Est. flux ", "(", 10^3*kg/yr, ")")),
-                                       unitUSGS = "Flux in thousands of kilograms per year",
+                                       unitUSGS = "Flux, in thousands of kilograms per year",
                                        shortCode = 8),
                   millionKgYear = new("fluxUnit",
                                       shortName = "   10^6 kg/yr",
@@ -89,7 +89,7 @@ fluxConst <- list(poundsDay = new("fluxUnit",
                                       unitExpressTiny = expression(paste("Flux ", "(", 10^6*kg/yr, ")")),
                                       unitEstimate = expression(paste("Estimated flux in ",10^6*kg/yr)),
                                       unitEstimateTiny = expression(paste("Est. flux ", "(", 10^6*kg/yr, ")")),
-                                      unitUSGS = "Flux in millions of kilograms per year",
+                                      unitUSGS = "Flux, in millions of kilograms per year",
                                       shortCode = 9),
                   billionKgYear = new("fluxUnit",
                                       shortName = "   10^9 kg/yr",
@@ -99,7 +99,7 @@ fluxConst <- list(poundsDay = new("fluxUnit",
                                       unitExpressTiny = expression(paste("Flux ", "(", 10^9*kg/yr, ")")),
                                       unitEstimate = expression(paste("Estimated flux in",10^9*kg/yr)),
                                       unitEstimateTiny = expression(paste("Est. flux ", "(", 10^9*kg/yr, ")")),
-                                      unitUSGS = "Flux in billions of kilograms per year",
+                                      unitUSGS = "Flux, in billions of kilograms per year",
                                       shortCode = 10),
                   thousandTonsDay = new("fluxUnit",
                                         shortName = " 10^3 tons/day",
@@ -109,7 +109,7 @@ fluxConst <- list(poundsDay = new("fluxUnit",
                                         unitExpressTiny = expression(paste("Flux ", "(", 10^3*tons/d, ")")),
                                         unitEstimate = expression(paste("Estimated flux in ",10^3*tons/day)),
                                         unitEstimateTiny = expression(paste("Est. flux ", "(", 10^3*tons/d, ")")),
-                                        unitUSGS = "Flux in thousands of tons per day",
+                                        unitUSGS = "Flux, in thousands of tons per day",
                                         shortCode = 11),
                   millionKgDay = new("fluxUnit",
                                      shortName = "   10^6 kg/day",
@@ -119,7 +119,7 @@ fluxConst <- list(poundsDay = new("fluxUnit",
                                      unitExpressTiny = expression(paste("Flux ", "(", 10^6*kg/d, ")")),
                                      unitEstimate = expression(paste("Estimated flux in ",10^6*kg/day)),
                                      unitEstimateTiny = expression(paste("Est. flux ", "(", 10^6*kg/d, ")")),
-                                     unitUSGS = "Flux in millions of kilograms per day",
+                                     unitUSGS = "Flux, in millions of kilograms per day",
                                      shortCode = 12),
                   kgYear = new("fluxUnit",
                                      shortName = "    kg/yr   ",
@@ -129,7 +129,7 @@ fluxConst <- list(poundsDay = new("fluxUnit",
                                      unitExpressTiny = expression("Flux (kg/yr)"),
                                      unitEstimate = expression("Estimated flux in kg/year"),
                                      unitEstimateTiny = expression("Est. flux in kg/yr"),
-                                     unitUSGS = "Flux in kilograms per year",
+                                     unitUSGS = "Flux, in kilograms per year",
                                      shortCode = 13)
 
 )
@@ -141,7 +141,7 @@ qConst <- list(cfs = new("qUnit",
                           qUnitExpress = expression(paste("Discharge in ",ft^3/s)),
                           qUnitTiny = expression(paste("Discharge ", "(", ft^3/s, ")")),
                           shortCode = 1,
-                          unitUSGS = "Discharge in cubic feet per second"
+                          unitUSGS = "Discharge, in cubic feet per second"
                           ),
                 cms = new("qUnit",
                           qShortName = "   cms  ",
@@ -150,7 +150,7 @@ qConst <- list(cfs = new("qUnit",
                           qUnitExpress = expression(paste("Discharge in ",m^3/s)),
                           qUnitTiny = expression(paste("Discharge ", "(", m^3/s, ")")),
                           shortCode = 2,
-                          unitUSGS = "Discharge in cubic meters per second"
+                          unitUSGS = "Discharge, in cubic meters per second"
                           ),
                 thousandCfs = new("qUnit",
                           qShortName = "10^3 cfs",
@@ -159,7 +159,7 @@ qConst <- list(cfs = new("qUnit",
                           qUnitExpress = expression(paste("Discharge in ",10^3*ft^3/s)),
                           qUnitTiny = expression(paste("Discharge ", "(", 10^3*ft^3/s, ")")),
                           shortCode = 3,
-                          unitUSGS = "Discharge in thousands of cubic feet per second"
+                          unitUSGS = "Discharge, in thousands of cubic feet per second"
                           ),
                 thousandCms = new("qUnit",
                           qShortName = "10^3 cms",
@@ -168,7 +168,7 @@ qConst <- list(cfs = new("qUnit",
                           qUnitExpress = expression(paste("Discharge in ",10^3*m^3/s)),
                           qUnitTiny = expression(paste("Discharge ", "(", 10^3*m^3/s, ")")),
                           shortCode = 4,
-                          unitUSGS = "Discharge in thousands of cubic meters per second"
+                          unitUSGS = "Discharge, in thousands of cubic meters per second"
                           ),
                 mmDay = new("qUnit",
                             qShortName = "mm/day",
@@ -177,7 +177,7 @@ qConst <- list(cfs = new("qUnit",
                             qUnitExpress = expression(paste("Discharge in ",mm^3/day)),
                             qUnitTiny = expression(paste("Discharge ", "(", mm^3/day, ")")),
                             shortCode = 5,
-                            unitUSGS = "Discharge in cubic millimeters per day"
+                            unitUSGS = "Discharge, in cubic millimeters per day"
                           )
 #                 ,mmYear = new("qUnit",
 #                           qUnitName = "Cubic Millimeters per Year",
